/*
m_risset_int - recursive form of the Risset filter (meant for internal use by
	m_risset only!)

DESCRIPTION

SYNTAX
aout m_risset_int ain, kstart_freq, kq, ioctave, kdirfac, kphs, kphs_shift, \
		kiter

INITIALIZATION
ioctave - Number of octaves to glide over
iwindow - window function (use GEN20 with type 6, max 1 and optio 1.8 - 2.2)
irise - Shape of the frequency modulator (use GEN5)

PERFORMANCE
ain - Audio input signal to be filter
kstart_freq - start frequency (lowest frequency of the Risset glissando)
kq - Bandwidth or Q of the bandpass filters
kdirfac - Direction factor:
	1: going up
	-1: going down
kphs - Input phasor to modulate frequency and amplitude
kphs_shift - Phase shift increment
kiter - Number of iteration

CREDITS
Author: Jeanette C.
*/

opcode m_risset_int, a, akkikkiiii
	ain, kstart_freq, kq, ioctave, kdirfac, kphs, iphs_shift, iiter, \
	iwindow, irise xin

	if (iiter >= (ioctave-1)) goto Output
	
	aband m_risset_int ain, kstart_freq, kq, ioctave, kdirfac, kphs, iphs_shift, (iiter+1), iwindow, irise

	; Start the real work
	Output:
	; Calculate the phasor for the amp modulator (always going forwards)
	kphasor wrap (kphs  + (iphs_shift * iiter)), 0, 1
	; calculate the phasor for the freq modulator (forwards or backwards
	; depending on the direction up/down
	kfphasor wrap (kphasor * kdirfac), 0, 1
	kfm table3 kfphasor*(ioctave/10), irise, 1, 0, 0
	kfm = kfm * kstart_freq

	; Calculate the amp modulator
	kam table3 kphasor, iwindow, 1, 0, 1

	; Process the input by the bandpass filter
	afilt butterbp ain*kam, kfm, kq
	amix = (aband + afilt)
	xout amix
endop
